/*
 * Renderer 6. The MIT License.
 * Copyright (c) 2022 rlkraft@pnw.edu
 * See LICENSE for details.
*/

import renderer.scene.*;
import renderer.scene.primitives.*;
import renderer.framebuffer.*;
import renderer.pipeline.*;

import java.awt.Color;

/**
   The near clipping plane stage in the renderer now clips
   off the line segment that straddles the camera plane,
   so the following line segment is no longer a problem.
*/
public class SomethingWrong_2_fixed
{
   public static void main(String[] args)
   {
      final Scene scene = new Scene("SomethingWrong_2_fixed");
      final Model model = new Model("Something Wrong 2");
      scene.addPosition(new Position(model));

      model.addVertex(new Vertex(0.9, 0.0, -0.9),  // edge of the view volume
                      new Vertex(0.9, 0.0,  0.9)); // behind the camera

      model.addColor(Color.white);

      model.addPrimitive(new LineSegment(0, 1, 0));

      final int width  = 100;
      final int height = 100;
      final FrameBuffer fb = new FrameBuffer(width, height, Color.darkGray);

      scene.debug = true;
      Clip.debug = true;
      Rasterize.debug = true;

      Pipeline.render(scene, fb);
      fb.dumpFB2File("SomethingWrong_2a_fixed.ppm");

      final Scene scene2 = scene.changeCamera(Camera.projOrtho());
      fb.clearFB();
      Pipeline.render(scene2, fb);
      fb.dumpFB2File("SomethingWrong_2b_fixed.ppm");
   }
}
